@@ -1,12 +1,13 @@
 package Image::ValidJpeg;
 
-use 5.010001;
+use 5.006002;
 use strict;
 use warnings;
 use Carp;
 
 require Exporter;
-use AutoLoader;
+
+our $VERSION = '1.001001';
 
 our @ISA = qw(Exporter);
 
@@ -18,7 +19,7 @@ our @ISA = qw(Exporter);
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
 our %EXPORT_TAGS = ( 
-    'all' => [ qw(
+    all => [ qw(
 check_tail
 check_jpeg
 check_all
@@ -28,7 +29,7 @@ SHORT
 EXTRA
 ) ], 
 
-'constants' => [ qw(
+constants => [ qw(
 GOOD
 BAD
 SHORT
@@ -39,45 +40,13 @@ EXTRA
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our @EXPORT = qw(
-	
-);
+our @EXPORT;
 
-our $VERSION = '1.001';
-
-sub AUTOLOAD {
-    # This AUTOLOAD is used to 'autoload' constants from the constant()
-    # XS function.
-
-    my $constname;
-    our $AUTOLOAD;
-    ($constname = $AUTOLOAD) =~ s/.*:://;
-    croak "&Image::ValidJpeg::constant not defined" if $constname eq 'constant';
-    my ($error, $val) = constant($constname);
-    if ($error) { croak $error; }
-    {
-	no strict 'refs';
-	# Fixed between 5.005_53 and 5.005_61
-#XXX	if ($] >= 5.00561) {
-#XXX	    *$AUTOLOAD = sub () { $val };
-#XXX	}
-#XXX	else {
-	    *$AUTOLOAD = sub { $val };
-#XXX	}
-    }
-    goto &$AUTOLOAD;
-}
 
 require XSLoader;
 XSLoader::load('Image::ValidJpeg', $VERSION);
 
-# Preloaded methods go here.
-
-# Autoload methods go after =cut, and are processed by the autosplit program.
-
-1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
@@ -89,7 +58,7 @@ Image::ValidJpeg - Perl extension for validating JPEG files.
 
  open $fh, 'FILE.jpg';
 
- if( Image::ValidJpeg::valid_jpeg($fh) ) {
+ if( Image::ValidJpeg::check_jpeg($fh) ) {
     print "FILE.jpg is bad\n";
  }
 
